Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3694)

Unified Diff: chrome/common/password_form_fill_data.cc

Issue 11000016: Move forms/ out of webkit/. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Response to review Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/password_form_fill_data.h ('k') | chrome/renderer/DEPS » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/password_form_fill_data.cc
diff --git a/webkit/forms/password_form_dom_manager.cc b/chrome/common/password_form_fill_data.cc
similarity index 51%
rename from webkit/forms/password_form_dom_manager.cc
rename to chrome/common/password_form_fill_data.cc
index 93545982fd1def4535e8378db1d130e8169cb0e6..c733719eda38b5e2a7c831a5b84a5094b5032749 100644
--- a/webkit/forms/password_form_dom_manager.cc
+++ b/chrome/common/password_form_fill_data.cc
@@ -1,20 +1,11 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "webkit/forms/password_form_dom_manager.h"
+#include "chrome/common/password_form_fill_data.h"
#include "base/logging.h"
-#include "third_party/WebKit/Source/WebKit/chromium/public/WebInputElement.h"
-#include "third_party/WebKit/Source/WebKit/chromium/public/WebPasswordFormData.h"
-#include "webkit/forms/form_field.h"
-
-using WebKit::WebFormElement;
-using WebKit::WebInputElement;
-using WebKit::WebPasswordFormData;
-
-namespace webkit {
-namespace forms {
+#include "chrome/common/form_field_data.h"
PasswordFormFillData::PasswordFormFillData() : wait_for_username(false) {
}
@@ -22,28 +13,19 @@ PasswordFormFillData::PasswordFormFillData() : wait_for_username(false) {
PasswordFormFillData::~PasswordFormFillData() {
}
-scoped_ptr<PasswordForm> PasswordFormDomManager::CreatePasswordForm(
- const WebFormElement& webform) {
- WebPasswordFormData web_password_form(webform);
- if (web_password_form.isValid())
- return scoped_ptr<PasswordForm>(new PasswordForm(web_password_form));
- return scoped_ptr<PasswordForm>();
-}
-
-// static
-void PasswordFormDomManager::InitFillData(
- const PasswordForm& form_on_page,
- const PasswordFormMap& matches,
- const PasswordForm* const preferred_match,
+void InitPasswordFormFillData(
+ const content::PasswordForm& form_on_page,
+ const content::PasswordFormMap& matches,
+ const content::PasswordForm* const preferred_match,
bool wait_for_username_before_autofill,
PasswordFormFillData* result) {
// Note that many of the |FormField| members are not initialized for
// |username_field| and |password_field| because they are currently not used
// by the password autocomplete code.
- FormField username_field;
+ FormFieldData username_field;
username_field.name = form_on_page.username_element;
username_field.value = preferred_match->username_value;
- FormField password_field;
+ FormFieldData password_field;
password_field.name = form_on_page.password_element;
password_field.value = preferred_match->password_value;
@@ -55,12 +37,9 @@ void PasswordFormDomManager::InitFillData(
result->wait_for_username = wait_for_username_before_autofill;
// Copy additional username/value pairs.
- PasswordFormMap::const_iterator iter;
+ content::PasswordFormMap::const_iterator iter;
for (iter = matches.begin(); iter != matches.end(); iter++) {
if (iter->second != preferred_match)
result->additional_logins[iter->first] = iter->second->password_value;
}
}
-
-} // namespace forms
-} // namespace webkit
« no previous file with comments | « chrome/common/password_form_fill_data.h ('k') | chrome/renderer/DEPS » ('j') | no next file with comments »

Powered by Google App Engine
@@ -22,28 +13,19 @@ PasswordFormFillData::PasswordFormFillData() : wait_for_username(false) {
bool wait_for_username_before_autofill,
PasswordFormFillData* result) {
- // Note that many of the |FormField| members are not initialized for
+ // Note that many of the |FormFieldData| members are not initialized for
// |username_field| and |password_field| because they are currently not used
// by the password autocomplete code.
This is Rietveld 408576698